@@ -7,7 +7,7 @@ def serialize_missing(missing: Missing) -> dict:
     serialized = {
         'missing': missing.missing,
         'context': missing.context.value,
-        'market': missing.market.value
+        'market': missing.market
     }
     if not is_empty(missing.description):
         serialized['description'] = missing.description
